Change "mctp instance id" to "pldm instance id"

Instance IDs are the ids given from the instanceID database
to the PLDM request and response messages.
Its not a MCTP thing but rather related to the PLDM messages.

Change-Id: I6eda652ec86cba691b8b2b848ca0c9227e4c05dc
Signed-off-by: Pavithra Barithaya <pavithrabarithaya07@gmail.com>
diff --git a/util/dbus.cpp b/util/dbus.cpp
index b69b23f..ebbdf67 100644
--- a/util/dbus.cpp
+++ b/util/dbus.cpp
@@ -534,8 +534,8 @@
     return true;
 }
 
-/** @brief Get MCTP instance associated with endpoint */
-bool getMctpInstance(uint8_t& mctpInstance, uint8_t Eid)
+/** @brief Get PLDM instance associated with endpoint */
+bool getPldmInstanceID(uint8_t& pldmInstanceID, uint8_t Eid)
 {
     constexpr auto service = "xyz.openbmc_project.PLDM";
     constexpr auto path = "/xyz/openbmc_project/pldm";
@@ -552,13 +552,13 @@
         // append endpoint ID
         method.append(Eid);
 
         // request MCTP instance ID
         auto reply = bus.call(method);
-        reply.read(mctpInstance);
+        reply.read(pldmInstanceID);
     }
     catch (const sdbusplus::exception_t& e)
     {
-        trace::err("get MCTP instance exception");
+        trace::err("get PLDM instance exception");
         trace::err(e.what());
         return false;
     }
@@ -552,13 +552,13 @@
         method.append(Eid);
 
-        // request MCTP instance ID
+        // request PLDM instance ID
         auto reply = bus.call(method);